﻿################################################################################
## Initialization
################################################################################

init offset = -1


################################################################################
## Styles
################################################################################

style default:
    properties gui.text_properties()
    language gui.language

style input:
    properties gui.text_properties("input", accent=True)
    adjust_spacing False

style hyperlink_text:
    properties gui.text_properties("hyperlink", accent=True)
    hover_underline True

style gui_text:
    properties gui.text_properties("interface")


style button:
    properties gui.button_properties("button")

style button_text is gui_text:
    properties gui.text_properties("button")
    yalign 0.5


style label_text is gui_text:
    properties gui.text_properties("label", accent=True)

style prompt_text is gui_text:
    properties gui.text_properties("prompt")


style bar:
    ysize gui.bar_size
    left_bar Frame("gui/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    xsize gui.bar_size
    top_bar Frame("gui/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    ysize gui.scrollbar_size
    base_bar Frame("gui/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

# old
#style vscrollbar:
#    xsize gui.scrollbar_size
#    base_bar Frame("gui/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
#    thumb Frame("gui/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    xsize gui.scrollbar_size
    xalign 0
    base_bar Frame("gui/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb "gui/scrollbar/vertical_idle_thumb.png"

style slider:
    ysize gui.slider_size
    base_bar Frame("gui/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/slider/horizontal_[prefix_]thumb.png"

style vslider:
    xsize gui.slider_size
    base_bar Frame("gui/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/slider/vertical_[prefix_]thumb.png"


style frame:
    padding gui.frame_borders.padding
    background Frame("gui/frame.png", gui.frame_borders, tile=gui.frame_tile)



################################################################################
## In-game screens
################################################################################


## Say screen ##################################################################
##
## The say screen is used to display dialogue to the player. It takes two
## parameters, who and what, which are the name of the speaking character and
## the text to be displayed, respectively. (The who parameter can be None if no
## name is given.)
##
## This screen must create a text displayable with id "what", as Ren'Py uses
## this to manage text display. It can also create displayables with id "who"
## and id "window" to apply style properties.
##
## https://www.renpy.org/doc/html/screen_special.html#say

screen say(who, what):
    style_prefix "say"

    window:
        id "window"

        if who is not None:

            window:
                id "namebox"
                style "namebox"
                text who id "who"

        text what id "what"


    ## If there's a side image, display it above the text. Do not display on the
    ## phone variant - there's no room.
    if not renpy.variant("small"):
        add SideImage() xalign 0.0 yalign 1.0


## Make the namebox available for styling through the Character object.
init python:
    config.character_id_prefixes.append('namebox')

style window is default
style say_label is default
style say_dialogue is default
style say_thought is say_dialogue

style namebox is default
style namebox_label is say_label


style window:
    text_align 0.5
    xalign 0.5
    #xpos 900
    xsize 1800
    yalign gui.textbox_yalign
    ysize gui.textbox_height

    #background Image("gui/textbox.png", xalign=1.0, yalign=1.0)

style window_princess:
    text_align 0.5
    xpos 100
    ypos -700
    xsize 500

style window_spooky_princess:
    text_align 0.5
    xpos 50
    ypos -700
    xsize 600

style window_spooky_princess_right:
    text_align 0.5
    xpos 1200
    ypos -700
    xsize 500

style window_spooky_princess_mid:
    text_align 0.5
    xalign 0.5
    ypos -700
    xsize 800

style window_princess_mid:
    text_align 0.5
    xpos 700
    ypos -700
    xsize 500

style truth_style:
    text_align 0.5
    xalign 0.5
    ypos 0
    xsize 1300

style truth_mid_style:
    text_align 0.5
    xalign 0.5
    ypos -500
    xsize 1200

style truthside:
    text_align 0.5
    xpos 100
    ypos -700
    xsize 800

style namebox:
    xpos gui.name_xpos
    xanchor gui.name_xalign
    xsize gui.namebox_width
    ypos gui.name_ypos
    ysize gui.namebox_height

    background Frame("gui/namebox.png", gui.namebox_borders, tile=gui.namebox_tile, xalign=gui.name_xalign)
    padding gui.namebox_borders.padding

style say_label:
    properties gui.text_properties("name", accent=True)
    xalign gui.name_xalign
    yalign 0.5

style say_dialogue:
    properties gui.text_properties("dialogue")

    xpos gui.dialogue_xpos
    xsize gui.dialogue_width
    ypos gui.dialogue_ypos

#########################################
## Disable Click
## temporarily disables ability to click so animations can play out

screen disableclick(time):
    timer time action Hide("disableclick")
    key "mouseup_1" action NullAction()
    key "K_SPACE" action NullAction()
    key "K_RETURN" action NullAction()


## Input screen ################################################################
##
## This screen is used to display renpy.input. The prompt parameter is used to
## pass a text prompt in.
##
## This screen must create an input displayable with id "input" to accept the
## various input parameters.
##
## https://www.renpy.org/doc/html/screen_special.html#input

screen input(prompt):
    style_prefix "input"

    window:

        vbox:
            xalign gui.dialogue_text_xalign
            xpos gui.dialogue_xpos
            xsize gui.dialogue_width
            ypos gui.dialogue_ypos

            text prompt style "input_prompt"
            input id "input"

style input_prompt is default

style input_prompt:
    xalign gui.dialogue_text_xalign
    properties gui.text_properties("input_prompt")

style input:
    xalign gui.dialogue_text_xalign
    xmaximum gui.dialogue_width


## Choice screen ###############################################################
##
## This screen is used to display the in-game choices presented by the menu
## statement. The one parameter, items, is a list of objects, each with caption
## and action fields.
##
## https://www.renpy.org/doc/html/screen_special.html#choice
style choice_vscrollbar is vscrollbar
style choice_vscrollbar:
    keyboard_focus False

screen choice(items):
    style_prefix "choice"
    default yadj = ui.adjustment()
    key "K_UP" action ScrollViewport(yadj, 'up')
    key "K_DOWN" action ScrollViewport(yadj, 'down')
    key "pad_lefty_neg" action ScrollViewport(yadj, 'up')
    key "pad_dpup_press" action ScrollViewport(yadj, 'up')
    key "pad_dpdown_press" action ScrollViewport(yadj, 'down')
    key "pad_lefty_pos" action ScrollViewport(yadj, 'down')
    #add "gui/choices_backdrop_test.png"
    add "gui/choices_backdrop.png"
    viewport yadjustment yadj:
        draggable True
        mousewheel True
        scrollbars "vertical"
        xalign 0.0
        xsize 430
        ysize 650
        xpos 1480
        ypos 25
        vbox:
            for idx, i in enumerate(items):
                if idx == 0:
                    textbutton i.caption action i.action default_focus True
                else:
                    textbutton i.caption action i.action

## When this is true, menu captions will be spoken by the narrator. When false,
## menu captions will be displayed as empty buttons.
define config.narrator_menu = True


style choice_vbox is vbox
style choice_button is button
style choice_button_text is button_text

style choice_vbox:
    xsize 350
    xpos 1470
    ypos 50

    spacing gui.choice_spacing

style choice_button is default:
    properties gui.button_properties("choice_button")

style choice_button_text is default:
    properties gui.button_text_properties("choice_button")
    #color "#ffffff"
    outlines [ (3, "#000000")]

######## Viewport Scrolling ##############
init python:
    class ScrollViewport(Action):

        def __init__(self, yadj, scroll_dir, step=(gui.interface_text_size)*2.0):
            self.yadj = yadj
            self.scroll_dir = scroll_dir
            self.step = step

        def __call__(self):
            # Don't confuse dir with the other use case for "up" which
            # refers to the state of the key (pressed/released)
            if self.scroll_dir == "up":
                if small_yadj:
                    self.yadj.change(self.yadj.value - (self.step/2))
                else:
                    self.yadj.change(self.yadj.value - self.step)
                renpy.display.behavior.queue_event('focus_up', up=False)
            else:
                if small_yadj:
                    self.yadj.change(self.yadj.value + (self.step/2))
                else:
                    self.yadj.change(self.yadj.value + self.step)
                renpy.display.behavior.queue_event('focus_down', up=False)
            renpy.restart_interaction


## Quick Menu screen ###########################################################
##
## The quick menu is displayed in-game to provide easy access to the out-of-game
## menus.

screen quick_menu():

    ## Ensure this appears on top of other screens.
    zorder 100

    if quick_menu:

        hbox:
            style_prefix "quick"

            xalign 0.5
            yalign 1.0

            #textbutton _("Vissza") action Rollback()
            textbutton _("Elôzmény") action ShowMenu('history')
            textbutton _("Kihagy") action Skip() alternate Skip(fast=True, confirm=True)
            textbutton _("Auto") action Preference("auto-forward", "toggle")
            textbutton _("Mentés") action ShowMenu('save')
            textbutton _("Gy.Mentés") action QuickSave()
            textbutton _("Gy.Betöltés") action QuickLoad()
            textbutton _("Elôny") action ShowMenu('preferences')


## This code ensures that the quick_menu screen is displayed in-game, whenever
## the player has not explicitly hidden the interface.
init python:
    config.overlay_screens.append("quick_menu")

default quick_menu = True

style quick_button is default
style quick_button_text is button_text

style quick_button:
    properties gui.button_properties("quick_button")

style quick_button_text:
    properties gui.button_text_properties("quick_button")


################################################################################
## Main and Game Menu Screens
################################################################################

## Navigation screen ###########################################################
##
## This screen is included in the main and game menus, and provides navigation
## to other menus, and to start the game.

screen navigation():

    default temp_main_menu_store = False

    if main_menu == False:
        vbox:
            style_prefix "navigation"

            xpos gui.navigation_xpos
            yalign 0.5

            spacing gui.navigation_spacing

            textbutton _("Elôzmény") action ShowMenu("history")

            textbutton _("Mentés") action ShowMenu("save")

            textbutton _("Betöltés") action ShowMenu("load")

            textbutton _("Preferenciák") action ShowMenu("preferences")

            if _in_replay:

                textbutton _("Ismétlés vége") action EndReplay(confirm=True)

            elif not main_menu:

                textbutton _("Fô Menü") action MainMenu()

            textbutton _("Megközelíthetôség") action ToggleScreen("_accessibility")

            textbutton _("Join our Discord") action OpenURL("https://discord.gg/xCnAeqkkEY")

            textbutton _("Follow us on Twitter") action OpenURL("https://twitter.com/blacktabbygames")

            textbutton _("Egyébb") action ShowMenu("about")

            if renpy.variant("pc") or (renpy.variant("web") and not renpy.variant("mobile")):

                ## Help isn't necessary or relevant to mobile devices.
                textbutton _("Segítség") action ShowMenu("help")

            if renpy.variant("pc"):

                ## The quit button is banned on iOS and unnecessary on Android and
                ## Web.
                textbutton _("Kilépés") action Quit(confirm=not main_menu)


style navigation_button is gui_button
#style navigation_button_text is gui_button_text

style navigation_button_text is default:
    #xalign 0.5
    properties gui.button_text_properties("choice_button")
    #color "#ffffff"
    outlines [ (3, "#000000")]

style navigation_button:
    size_group "navigáció"
    properties gui.button_properties("navigation_button")

style navigation_button_text:
    properties gui.button_text_properties("navigation_button")

## screen ending

screen song():
    $ song_ypos = 200
    if final_ending == "good":
        vbox:
            xalign 0.5
            text "{size=30}A hercegnô{/size}" ypos song_ypos xpos 0
            $ song_ypos += 25
            text "{size=30}A világmegváltó{/size}" ypos song_ypos xpos 0
            $ song_ypos += 25
            text "{size=30}Örök boldogság (Hurrá, megcsináltad!){/size}" ypos song_ypos xpos 0
    else:
        hbox:
            xalign 0.5
            vbox:
                text "{size=30}A hercegnô{/size}" ypos song_ypos xpos 0
                $ song_ypos += 25
                if first_princess != "stranger":
                    text "{size=30}A világboldogító{/size}" ypos song_ypos xpos 0
                    $ song_ypos += 25
                if final_ending != "oblivion":
                    if oblivion_when_met == 0:
                        text "{size=30}Feledés{/size}" ypos song_ypos xpos 0
                        $ song_ypos += 25
                if loops_finished >= 1:
                    if first_mound == "adversary":
                        text "{size=30}A dal, amit a vérünkbe írunk{/size}" ypos song_ypos xpos 0
                    elif first_mound == "eye":
                        text "{size=30}A tû szeme{/size}" ypos song_ypos xpos 0
                    elif first_mound == "beast":
                        text "{size=30}Sokkal több vagyok, mint te{/size}" ypos song_ypos xpos 0
                    elif first_mound == "den":
                        text "{size=30}A Den{/size}" ypos song_ypos xpos 0
                    elif first_mound == "damsel":
                        text "{size=30}Mindig ilyen könnyû volt{/size}" ypos song_ypos xpos 0
                    elif first_mound == "dereal":
                        text "{size=30}Csak boldoggá akarlak tenni{/size}" ypos song_ypos xpos 0
                    elif first_mound == "nightmare":
                        text "{size=30}Meg akarom nézni, ahogy történik{/size}" ypos song_ypos xpos 0
                    elif first_mound == "clarity":
                        text "{size=30}A tisztánlátás pillanata{/size}" ypos song_ypos xpos 0
                    elif first_mound == "prisonerhead":
                        text "{size=30}Eyes on Me{/size}" ypos song_ypos xpos 0
                    elif first_mound == "prisonerchain":
                        text "{size=30}Nem szeretem a Small Talkot{/size}" ypos song_ypos xpos 0
                    elif first_mound == "razorheart":
                        text "{size=30}A Borotva{/size}" ypos song_ypos xpos 0
                    elif first_mound == "razor":
                        text "{size=30}Kölcsönösen biztosított megsemmisítés{/size}" ypos song_ypos xpos 0
                    elif first_mound == "spectre":
                        if spectre_end == "free":
                            text "{size=30}Egy fuvarozás{/size}" ypos song_ypos xpos 0
                        else:
                            text "{size=30}A Szellem{/size}" ypos song_ypos xpos 0
                    elif first_mound == "stranger":
                        text "{size=30}Mindennek lenni{/size}" ypos song_ypos xpos 0
                    elif first_mound == "tower":
                        text "{size=30}Könyörgés{/size}" ypos song_ypos xpos 0
                    elif first_mound == "apotheosis":
                        if final_ending != "liberation":
                            text "{size=30}Az apoteózis{/size}" ypos song_ypos xpos 0
                        else:
                            text "{size=30}Hamis bálvány{/size}" ypos song_ypos xpos 0
                    elif first_mound == "witch":
                        text "{size=30}Ez a természetünkben van{/size}" ypos song_ypos xpos 0
                    elif first_mound == "thorn":
                        if thorn_end == "free_kiss":
                            text "{size=30}Egy csók egy tövisrôl{/size}" ypos song_ypos xpos 0
                        elif thorn_end == "free":
                            text "{size=30}A tövis{/size}" ypos song_ypos xpos 0
                        else:
                            text "{size=30}Egy pillanat örökre megragadva{/size}" ypos song_ypos xpos 0
                    elif first_mound == "fury":
                        text "{size=30}A düh{/size}" ypos song_ypos xpos 0
                    elif first_mound == "greydamsel":
                        text "{size=30}A szürke (tûz){/size}" ypos song_ypos xpos 0
                    elif first_mound == "greyprisoner":
                        text "{size=30}A szürke (víz){/size}" ypos song_ypos xpos 0
                    elif first_mound == "wildnerves":
                        text "{size=30}A Vadon{/size}" ypos song_ypos xpos 0
                    elif first_mound == "wildwound":
                        text "{size=30}A Vadon{/size}" ypos song_ypos xpos 0
                    elif first_mound == "wraith":
                        text "{size=30}I'm Taking What I'm Owed (Elveszem, ami jár){/size}" ypos song_ypos xpos 0
                    $ song_ypos += 25
                    text "{size=30}Az elmozduló domb mozgalom I{/size}" ypos song_ypos xpos 0
                    $ song_ypos += 25

                # second loop
                if final_ending != "oblivion":
                    if oblivion_when_met == 1:
                        text "{size=30}Feledés{/size}" ypos song_ypos xpos 0
                        $ song_ypos += 25
                if loops_finished >= 2:
                    if second_mound == "adversary":
                        text "{size=30}A dal, amit a vérünkbe írunk{/size}" ypos song_ypos xpos 0
                    elif second_mound == "eye":
                        text "{size=30}A tû szeme{/size}" ypos song_ypos xpos 0
                    elif second_mound == "beast":
                        text "{size=30}Sokkal Több vagyok, mint te{/size}" ypos song_ypos xpos 0
                    elif second_mound == "den":
                        text "{size=30}A Den{/size}" ypos song_ypos xpos 0
                    elif second_mound == "damsel":
                        text "{size=30}Mindig ilyen könnyû volt{/size}" ypos song_ypos xpos 0
                    elif second_mound == "dereal":
                        text "{size=30}Csak boldoggá akarlak tenni{/size}" ypos song_ypos xpos 0
                    elif second_mound == "nightmare":
                        text "{size=30}Meg akarom nézni, ahogy történik{/size}" ypos song_ypos xpos 0
                    elif second_mound == "clarity":
                        text "{size=30}A tisztánlátás pillanata{/size}" ypos song_ypos xpos 0
                    elif second_mound == "prisonerhead":
                        text "{size=30}Eyes on Me{/size}" ypos song_ypos xpos 0
                    elif second_mound == "prisonerchain":
                        text "{size=30}Nem szeretem a Small Talkot{/size}" ypos song_ypos xpos 0
                    elif second_mound == "razorheart":
                        text "{size=30}A Borotva{/size}" ypos song_ypos xpos 0
                    elif second_mound == "razor":
                        text "{size=30}Kölcsönösen biztosított megsemmisítés{/size}" ypos song_ypos xpos 0
                    elif second_mound == "spectre":
                        if spectre_end == "free":
                            text "{size=30}Egy fuvarozás{/size}" ypos song_ypos xpos 0
                        else:
                            text "{size=30}A Szellem{/size}" ypos song_ypos xpos 0
                    elif second_mound == "stranger":
                        text "{size=30}Mindennek lenni{/size}" ypos song_ypos xpos 0
                    elif second_mound == "tower":
                        text "{size=30}Könyörgés{/size}" ypos song_ypos xpos 0
                    elif second_mound == "apotheosis":
                        if final_ending != "liberation":
                            text "{size=30}Az apoteózis{/size}" ypos song_ypos xpos 0
                        else:
                            text "{size=30}Hamis bálvány{/size}" ypos song_ypos xpos 0
                    elif second_mound == "witch":
                        text "{size=30}Ez a természetünkben van{/size}" ypos song_ypos xpos 0
                    elif second_mound == "thorn":
                        if thorn_end == "free_kiss":
                            text "{size=30}Egy csók egy tövisrôl{/size}" ypos song_ypos xpos 0
                        elif thorn_end == "free":
                            text "{size=30}A tövis{/size}" ypos song_ypos xpos 0
                        else:
                            text "{size=30}Egy pillanat örökre megragadva{/size}" ypos song_ypos xpos 0
                    elif second_mound == "fury":
                        text "{size=30}A düh{/size}" ypos song_ypos xpos 0
                    elif second_mound == "greydamsel":
                        text "{size=30}A szürke (tûz){/size}" ypos song_ypos xpos 0
                    elif second_mound == "greyprisoner":
                        text "{size=30}A szürke (víz){/size}" ypos song_ypos xpos 0
                    elif second_mound == "wildnerves":
                        text "{size=30}A Vadon{/size}" ypos song_ypos xpos 0
                    elif second_mound == "wildwound":
                        text "{size=30}A Vadon{/size}" ypos song_ypos xpos 0
                    elif second_mound == "wraith":
                        text "{size=30}I'm Taking What I'm Owed (Elveszem, ami jár){/size}" ypos song_ypos xpos 0
                    $ song_ypos += 25
                    text "{size=30}A változó domb mozgalom II{/size}" ypos song_ypos xpos 0
                    $ song_ypos += 25

                # third mound
                if final_ending != "oblivion":
                    if oblivion_when_met == 2:
                        text "{size=30}Feledés{/size}" ypos song_ypos xpos 0
                        $ song_ypos += 25
                if loops_finished >= 3:
                    if third_mound == "adversary":
                        text "{size=30}A dal, amit a vérünkbe írunk{/size}" ypos song_ypos xpos 0
                    elif third_mound == "eye":
                        text "{size=30}A tû szeme{/size}" ypos song_ypos xpos 0
                    elif third_mound == "beast":
                        text "{size=30}Sokkal Több vagyok, mint te{/size}" ypos song_ypos xpos 0
                    elif third_mound == "den":
                        text "{size=30}A Den{/size}" ypos song_ypos xpos 0
                    elif third_mound == "damsel":
                        text "{size=30}Mindig ilyen könnyû volt{/size}" ypos song_ypos xpos 0
                    elif third_mound == "dereal":
                        text "{size=30}Csak boldoggá akarlak tenni{/size}" ypos song_ypos xpos 0
                    elif third_mound == "nightmare":
                        text "{size=30}Meg akarom nézni, ahogy történik{/size}" ypos song_ypos xpos 0
                    elif third_mound == "clarity":
                        text "{size=30}A tisztánlátás pillanata{/size}" ypos song_ypos xpos 0
                    elif third_mound == "prisonerhead":
                        text "{size=30}Eyes on Me{/size}" ypos song_ypos xpos 0
                    elif third_mound == "prisonerchain":
                        text "{size=30}Nem szeretem a Small Talkot{/size}" ypos song_ypos xpos 0
                    elif third_mound == "razorheart":
                        text "{size=30}A Borotva{/size}" ypos song_ypos xpos 0
                    elif third_mound == "razor":
                        text "{size=30}Kölcsönösen biztosított megsemmisítés{/size}" ypos song_ypos xpos 0
                    elif third_mound == "spectre":
                        if spectre_end == "free":
                            text "{size=30}Egy fuvarozás{/size}" ypos song_ypos xpos 0
                        else:
                            text "{size=30}A Szellem{/size}" ypos song_ypos xpos 0
                    elif third_mound == "stranger":
                        text "{size=30}Mindennek lenni{/size}" ypos song_ypos xpos 0
                    elif third_mound == "tower":
                        text "{size=30}Könyörgés{/size}" ypos song_ypos xpos 0
                    elif third_mound == "apotheosis":
                        if final_ending != "liberation":
                            text "{size=30}Az apoteózis{/size}" ypos song_ypos xpos 0
                        else:
                            text "{size=30}Hamis bálvány{/size}" ypos song_ypos xpos 0
                    elif third_mound == "witch":
                        text "{size=30}Ez a természetünkben van{/size}" ypos song_ypos xpos 0
                    elif third_mound == "thorn":
                        if thorn_end == "free_kiss":
                            text "{size=30}Egy csók egy tövisrôl{/size}" ypos song_ypos xpos 0
                        elif thorn_end == "free":
                            text "{size=30}A tövis{/size}" ypos song_ypos xpos 0
                        else:
                            text "{size=30}Egy pillanat örökre megragadva{/size}" ypos song_ypos xpos 0
                    elif third_mound == "fury":
                        text "{size=30}A düh{/size}" ypos song_ypos xpos 0
                    elif third_mound == "greydamsel":
                        text "{size=30}A szürke (tûz){/size}" ypos song_ypos xpos 0
                    elif third_mound == "greyprisoner":
                        text "{size=30}A szürke (víz){/size}" ypos song_ypos xpos 0
                    elif third_mound == "wildnerves":
                        text "{size=30}A Vadon{/size}" ypos song_ypos xpos 0
                    elif third_mound == "wildwound":
                        text "{size=30}A Vadon{/size}" ypos song_ypos xpos 0
                    elif third_mound == "wraith":
                        text "{size=30}I'm Taking What I'm Owed (Elveszem, ami jár){/size}" ypos song_ypos xpos 0
                    $ song_ypos += 25
                    text "{size=30}A változó domb mozgalom III{/size}" ypos song_ypos xpos 0
                    $ song_ypos += 25

            vbox:
                $ song_ypos = 200
                xalign 1.0
                # fourth mound
                if final_ending != "oblivion":
                    if oblivion_when_met == 3:
                        text "{size=30}Feledés{/size}" ypos song_ypos xpos 150
                        $ song_ypos += 25
                if loops_finished >= 4:
                    if fourth_mound == "adversary":
                        text "{size=30}A dal, amit a vérünkbe írunk{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "eye":
                        text "{size=30}A tû szeme{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "beast":
                        text "{size=30}Sokkal több vagyok, mint te{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "den":
                        text "{size=30}A Den{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "damsel":
                        text "{size=30}Mindig ilyen könnyû volt{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "dereal":
                        text "{size=30}Csak boldoggá akarlak tenni{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "nightmare":
                        text "{size=30}Meg akarom nézni, ahogy történik{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "clarity":
                        text "{size=30}A tisztánlátás pillanata{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "prisonerhead":
                        text "{size=30}Eyes on Me{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "prisonerchain":
                        text "{size=30}Nem szeretem a Small Talkot{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "razorheart":
                        text "{size=30}A Borotva{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "razor":
                        text "{size=30}Kölcsönösen biztosított megsemmisítés{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "spectre":
                        if spectre_end == "free":
                            text "{size=30}Egy fuvarozás{/size}" ypos song_ypos xpos 150
                        else:
                            text "{size=30}A Szellem{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "stranger":
                        text "{size=30}Mindennek lenni{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "tower":
                        text "{size=30}Könyörgés{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "apotheosis":
                        if final_ending != "liberation":
                            text "{size=30}Az apoteózis{/size}" ypos song_ypos xpos 150
                        else:
                            text "{size=30}Hamis bálvány{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "witch":
                        text "{size=30}Ez a természetünkben van{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "thorn":
                        if thorn_end == "free_kiss":
                            text "{size=30}Egy csók egy tövisrôl{/size}" ypos song_ypos xpos 150
                        elif thorn_end == "free":
                            text "{size=30}A tövis{/size}" ypos song_ypos xpos 150
                        else:
                            text "{size=30}Egy pillanat örökre megragadva{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "fury":
                        text "{size=30}A düh{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "greydamsel":
                        text "{size=30}A szürke (tûz){/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "greyprisoner":
                        text "{size=30}A szürke (víz){/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "wildnerves":
                        text "{size=30}A Vadon{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "wildwound":
                        text "{size=30}A Vadon{/size}" ypos song_ypos xpos 150
                    elif fourth_mound == "wraith":
                        text "{size=30}I'm Taking What I'm Owed (Elveszem, ami jár){/size}" ypos song_ypos xpos 150
                    $ song_ypos += 25
                    text "{size=30}A változó domb mozgalom IV{/size}" ypos song_ypos xpos 150
                    $ song_ypos += 25

                # fifth mound

                if loops_finished >= 5:
                    if fifth_mound == "adversary":
                        text "{size=30}A dal, amit a vérünkbe írunk{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "eye":
                        text "{size=30}A tû szeme{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "beast":
                        text "{size=30}Sokkal több vagyok, mint te{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "den":
                        text "{size=30}A Den{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "damsel":
                        text "{size=30}Mindig ilyen könnyû volt{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "dereal":
                        text "{size=30}Csak boldoggá akarlak tenni{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "nightmare":
                        text "{size=30}Meg akarom nézni, ahogy történik{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "clarity":
                        text "{size=30}A tisztánlátás pillanata{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "prisonerhead":
                        text "{size=30}Eyes on Me{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "prisonerchain":
                        text "{size=30}Nem szeretem a Small Talkot{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "razorheart":
                        text "{size=30}A Borotva{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "razor":
                        text "{size=30}Kölcsönösen biztosított megsemmisítés{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "spectre":
                        if spectre_end == "free":
                            text "{size=30}Egy fuvarozás{/size}" ypos song_ypos xpos 150
                        else:
                            text "{size=30}A Szellem{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "stranger":
                        text "{size=30}Mindennek lenni{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "tower":
                        text "{size=30}Könyörgés{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "apotheosis":
                        if final_ending != "liberation":
                            text "{size=30}Az apoteózis{/size}" ypos song_ypos xpos 150
                        else:
                            text "{size=30}Hamis bálvány{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "witch":
                        text "{size=30}Ez a természetünkben van{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "thorn":
                        if thorn_end == "free_kiss":
                            text "{size=30}Egy csók egy tövisrôl{/size}" ypos song_ypos xpos 150
                        elif thorn_end == "free":
                            text "{size=30}A tövis{/size}" ypos song_ypos xpos 150
                        else:
                            text "{size=30}Egy pillanat örökre megragadva{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "fury":
                        text "{size=30}A düh{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "greydamsel":
                        text "{size=30}A szürke (tûz){/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "greyprisoner":
                        text "{size=30}A szürke (víz){/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "wildnerves":
                        text "{size=30}A Vadon{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "wildwound":
                        text "{size=30}A Vadon{/size}" ypos song_ypos xpos 150
                    elif fifth_mound == "wraith":
                        text "{size=30}I'm Taking What I'm Owed (Elveszem, ami jár){/size}" ypos song_ypos xpos 150
                    $ song_ypos += 25
                    if final_ending != "slay" and final_ending != "good":
                        text "{size=30}A hosszú csend{/size}" ypos song_ypos xpos 150
                        $ song_ypos += 25
                    text "{size=30}A változó halom mozgalom V{/size}" ypos song_ypos xpos 150
                    $ song_ypos += 25
                    if mound_fight_triggered:
                        text "{size=30}Átalakulás{/size}" ypos song_ypos xpos 150
                        $ song_ypos += 25
                if final_ending == "oblivion":
                    text "{size=30}Feledés{/size}" ypos song_ypos xpos 150
                if final_ending == "liberation":
                    text "{size=30}Az apoteózis{/size}" ypos song_ypos xpos 150
                if final_ending == "slay":
                    text "{size=30}A hosszú csend{/size}" ypos song_ypos xpos 150
                if final_ending == "loop":
                    text "{size=30}Mindennek vége, valami újnak a kezdete{/size}" ypos song_ypos xpos 150
                if final_ending == "good":
                    text "{size=30}A hosszú csend{/size}" ypos song_ypos xpos 150
                if final_ending == "leave":
                    text "{size=30}Az ismeretlen együtt{/size}" ypos song_ypos xpos 150





screen ending():
    style_prefix "navigation"

    imagebutton:
        #auto "images/credits/sh_end_%s.png"
        auto "images/credits/sh_border_%s.png"
        xpos 99
        ypos 425
        action OpenURL("steam://openurl/https://store.steampowered.com/app/1609230/Scarlet_Hollow/")

    imagebutton:
        auto "images/credits/wl_end_%s.png"
        xpos 1286
        ypos 425
        action OpenURL("steam://openurl/https://store.steampowered.com/app/1989270/Slay_the_Princess/")

    imagebutton:
        auto "images/credits/discord_end_%s.png"
        xpos 660
        ypos 841
        action OpenURL("https://discord.com/invite/xCnAeqkkEY")

    #textbutton _("Folytatás") action Jump("credits") xpos 1412 ypos 941


    imagebutton:
        #auto "images/credits/continue_end_%s.png"
        #xpos 1612
        #ypos 941
        auto "images/credits/continue_%s.png"
        xpos 1412
        ypos 941
        action Jump("credits")

## Main Menu screen ############################################################
##
## Used to display the main menu when Ren'Py starts.
##
## https://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu():

    ## This ensures that any other menu screen is replaced.
    tag menu

    if persistent.performance_mode == False:
        add Movie(size=(1920, 1080))
        on "show" action Play("movie", "images/menu/main_menu.webm", loop=True)
        on "hide" action Stop("movie")
        on "hide" action Hide(screen = "navigation")
        on "replace" action Play("movie", "images/menu/main_menu.webm", loop=True)
        on "replace" action Show(screen = "navigation")
        on "replaced" action Stop("movie")
    else:
        add "menu static"
    #add "choices_backdrop_menu"
    #add "logo_menu_final"
    add "logo_menu_alt"

    vbox:
        style_prefix "main_menu"
        xalign 0.5
        #xpos 1737
        xpos 237
        yalign 0.45

        spacing gui.navigation_spacing
        textbutton _("Játék Indítása") action Start()

        textbutton _("Játék Betöltése") action ShowMenu("load")

        textbutton _("Preferenciák") action ShowMenu("preferences")

        if renpy.variant("pc") or (renpy.variant("web") and not renpy.variant("mobile")):

            ## Help isn't necessary or relevant to mobile devices.
            textbutton _("Vezérlôk") action ShowMenu("help")

        #textbutton _("Wishlist on Steam") action OpenURL("steam://openurl/https://store.steampowered.com/app/1989270/Slay_the_Princess")

        # STEAM
        #textbutton _("Visit Scarlet Hollow") action OpenURL("steam://openurl/https://store.steampowered.com/app/1609230/Scarlet_Hollow/")

        # GOG
        textbutton _("Visit Scarlet Hollow") action OpenURL("https://www.gog.com/en/game/scarlet_hollow")

        textbutton _("Join Our Discord") action OpenURL("https://discord.gg/blacktabbygames")

        textbutton _("Follow us on Twitter") action OpenURL("https://twitter.com/blacktabbygames")

        #textbutton _("Follow us on Twitter") action OpenURL("https://twitter.com/blacktabbygames")

        if renpy.variant("pc"):

            ## The quit button is banned on iOS and unnecessary on Android and
            ## Web.
            textbutton _("Kilépés") action Quit(confirm=not main_menu)

    ## This empty frame darkens the main menu.
    #frame:
    #    style "main_menu_frame"

    ## The use statement includes another screen inside this one. The actual
    ## contents of the main menu are in the navigation screen.
    #use navigation

    #imagebutton:
    #    auto "images/menu/menu_buttons/start_%s.png"
    #    xalign 0.5
    #    xpos 1540
    #    ypos 320
    # old
        #xpos 104
        #ypos 793
        #action Start()

    #imagebutton:
    #    auto "images/menu/menu_buttons/load_%s.png"
    #    xalign 0.5
    #    xpos 1540
    #    ypos 420
        #xpos 463
        #ypos 793
    #    action ShowMenu("load")

    #imagebutton:
    #    auto "images/menu/menu_buttons/options_%s.png"
    #    xalign 0.5
    #    xpos 1540
    #    ypos 520
    # old
        #xpos 769
        #ypos 793
    #    action ShowMenu("preferences")

    #if renpy.variant("pc") or (renpy.variant("web") and not renpy.variant("mobile")):
    #    imagebutton:
    #        auto "images/menu/menu_buttons/controls_%s.png"
    #        xalign 0.5
    #        xpos 1540
    #        ypos 620
    # old
            #xpos 1109
            #ypos 793
    #        action ShowMenu("help")



    #imagebutton:
    #    auto "images/menu/menu_buttons/wishlist_%s.png"
    #    xalign 0.5
    #    xpos 1540
    #    ypos 720
        # old
        #xpos 292
        #ypos 940
    #    action OpenURL("steam://openurl/https://store.steampowered.com/app/1989270/Slay_the_Princess")

    #imagebutton:
    #    auto "images/menu/menu_buttons/sh_%s.png"
    #    xalign 0.5
    #    xpos 1540
    #    ypos 820
    # old
        #xpos 935
        #ypos 945
        #action OpenURL("steam://openurl/https://store.steampowered.com/app/1609230/Scarlet_Hollow/")

    #if renpy.variant("pc"):
    #    imagebutton:
    #        auto "images/menu/menu_buttons/quit_%s.png"
    #        xalign 0.5
    #        xpos 1540
    #        ypos 920
    # old
            #xpos 1527
            #ypos 793
    #        action Quit(confirm=not main_menu)

    if gui.show_name:

        vbox:
            style "main_menu_vbox"

            text "[config.name!t]":
                style "main_menu_title"

            text "[config.version]":
                style "main_menu_version"


style main_menu_frame is empty
style main_menu_vbox is vbox
style main_menu_text is gui_text
style main_menu_title is main_menu_text
style main_menu_version is main_menu_text

style main_menu_frame:
    xsize 420
    yfill True

    background "gui/overlay/main_menu.png"

style main_menu_vbox:
    xalign 0.5
    xoffset -30
    xmaximum 1200
    yalign 1.0
    yoffset -30

style main_menu_button:
    xalign 0.5

style main_menu_button_text is default:
    xalign 0.5
    properties gui.button_text_properties("choice_button")
    #color "#ffffff"
    outlines [ (3, "#000000")]

style main_menu_text:
    properties gui.text_properties("main_menu", accent=True)

style main_menu_title:
    properties gui.text_properties("title")

style main_menu_version:
    properties gui.text_properties("version")


## Game Menu screen ############################################################
##
## This lays out the basic common structure of a game menu screen. It's called
## with the screen title, and displays the background, title, and navigation.
##
## The scroll parameter can be None, or one of "viewport" or "vpgrid". When
## this screen is intended to be used with one or more children, which are
## transcluded (placed) inside it.

screen game_menu(title, scroll=None, yinitial=0.0):

    style_prefix "game_menu"

    if main_menu:
        add gui.main_menu_background
    else:
        add gui.game_menu_background

    frame:
        style "game_menu_outer_frame"

        hbox:

            ## Reserve space for the navigation section.
            frame:
                style "game_menu_navigation_frame"

            frame:
                style "game_menu_content_frame"

                if scroll == "viewport":

                    viewport:
                        yinitial yinitial
                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        vbox:
                            transclude

                elif scroll == "vpgrid":

                    vpgrid:
                        cols 1
                        yinitial yinitial

                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        transclude

                else:

                    transclude

    use navigation

    textbutton _("Vissza"):
        style "return_button"

        action Return()

    label title

    if main_menu:
        key "game_menu" action ShowMenu("main_menu")


style game_menu_outer_frame is empty
style game_menu_navigation_frame is empty
style game_menu_content_frame is empty
style game_menu_viewport is gui_viewport
style game_menu_side is gui_side
style game_menu_scrollbar is gui_vscrollbar

style game_menu_label is gui_label
style game_menu_label_text is gui_label_text

style return_button is navigation_button
style return_button_text is navigation_button_text

style game_menu_outer_frame:
    bottom_padding 45
    top_padding 180

    background "gui/overlay/game_menu.png"

style game_menu_navigation_frame:
    xsize 420
    yfill True

style game_menu_content_frame:
    left_margin 60
    right_margin 30
    top_margin 15

style game_menu_viewport:
    xsize 1380

style game_menu_vscrollbar:
    unscrollable gui.unscrollable

style game_menu_side:
    spacing 15

style game_menu_label:
    xpos 75
    ysize 180

style game_menu_label_text:
    size gui.title_text_size
    color gui.accent_color
    yalign 0.5

style return_button:
    xpos gui.navigation_xpos
    yalign 1.0
    yoffset -45


## About screen ################################################################
##
## This screen gives credit and copyright information about the game and Ren'Py.
##
## There's nothing special about this screen, and hence it also serves as an
## example of how to make a custom screen.

screen about():

    tag menu

    ## This use statement includes the game_menu screen inside this one. The
    ## vbox child is then included inside the viewport inside the game_menu
    ## screen.
    use game_menu(_("Egyébb"), scroll="viewport"):

        style_prefix "about"

        vbox:

            label "[config.name!t]"
            text _("Verzió [config.version!t]\n")

            ## gui.about is usually set in options.rpy.
            if gui.about:
                text "[gui.arról!t]\n"

            text _("Made with {a=https://www.renpy.org/}Ren'Py{/a} [renpy.version_only].\n\n[renpy.license!t]")


style about_label is gui_label
style about_label_text is gui_label_text
style about_text is gui_text

style about_label_text:
    size gui.label_text_size


## Load and Save screens #######################################################
##
## These screens are responsible for letting the player save the game and load
## it again. Since they share nearly everything in common, both are implemented
## in terms of a third screen, file_slots.
##
## https://www.renpy.org/doc/html/screen_special.html#save https://
## www.renpy.org/doc/html/screen_special.html#load

screen save():

    tag menu

    use file_slots(_("Mentés"))


screen load():

    tag menu

    use file_slots(_("Betöltés"))


screen file_slots(title):

    default page_name_value = FilePageNameInputValue(pattern=_("Lap {}"), auto=_("Automatikus mentés"), quick=_("Gyors Mentés"))

    use game_menu(title):

        fixed:

            ## This ensures the input will get the enter event before any of the
            ## buttons do.
            order_reverse True

            ## The page name, which can be edited by clicking on a button.
            button:
                style "page_label"

                key_events True
                xalign 0.5
                action page_name_value.Toggle()

                input:
                    style "page_label_text"
                    value page_name_value

            ## The grid of file slots.
            grid gui.file_slot_cols gui.file_slot_rows:
                style_prefix "slot"

                xalign 0.5
                yalign 0.5

                spacing gui.slot_spacing

                for i in range(gui.file_slot_cols * gui.file_slot_rows):

                    $ slot = i + 1

                    button:
                        action FileAction(slot)

                        has vbox

                        add FileScreenshot(slot) xalign 0.5

                        text FileTime(slot, format=_("{#file_time}%A, %B %d %Y, %H:%M"), empty=_("empty slot")):
                            style "slot_time_text"

                        text FileSaveName(slot):
                            style "slot_name_text"

                        key "save_delete" action FileDelete(slot)

            ## Buttons to access other pages.
            hbox:
                style_prefix "page"

                xalign 0.5
                yalign 1.0

                spacing gui.page_spacing

                textbutton _("<") action FilePagePrevious()

                if config.has_autosave:
                    textbutton _("{#auto_page}A") action FilePage("auto")

                if config.has_quicksave:
                    textbutton _("{#quick_page}Q") action FilePage("quick")

                ## range(1, 10) gives the numbers from 1 to 9.
                for page in range(1, 10):
                    textbutton "[page]" action FilePage(page)

                textbutton _(">") action FilePageNext()


style page_label is gui_label
style page_label_text is gui_label_text
style page_button is gui_button
style page_button_text is gui_button_text

style slot_button is gui_button
style slot_button_text is gui_button_text
style slot_time_text is slot_button_text
style slot_name_text is slot_button_text

style page_label:
    xpadding 75
    ypadding 5

style page_label_text:
    text_align 0.5
    layout "subtitle"
    hover_color gui.hover_color

style page_button:
    properties gui.button_properties("page_button")

style page_button_text:
    properties gui.button_text_properties("page_button")

style slot_button:
    properties gui.button_properties("slot_button")

style slot_button_text:
    properties gui.button_text_properties("slot_button")


## Preferences screen ##########################################################
##
## The preferences screen allows the player to configure the game to better suit
## themselves.
##
## https://www.renpy.org/doc/html/screen_special.html#preferences

screen preferences():

    tag menu

    use game_menu(_("Preferences"), scroll="viewport"):

        vbox:

            hbox:
                box_wrap True

                if renpy.variant("pc") or renpy.variant("web"):

                    vbox:
                        style_prefix "radio"
                        label _("Display")
                        textbutton _("Window") action Preference("display", "window")
                        textbutton _("Fullscreen") action Preference("display", "fullscreen")

                vbox:
                    style_prefix "check"
                    label _("Kihagy")
                    textbutton _("Unseen Text") action Preference("skip", "toggle")
                    textbutton _("After Choices") action Preference("after choices", "toggle")
                    textbutton _("Transitions") action InvertSelected(Preference("transitions", "toggle"))


                vbox:
                    style_prefix "radio"
                    label _("Quick Menu Visibility")
                    textbutton _("Visible") action [SetVariable("persistent.quick_menu", True), SetVariable("quick_menu", True)]
                    textbutton _("Hidden") action [SetVariable("persistent.quick_menu", False), SetVariable("quick_menu", False)]

                #vbox:
                #    style_prefix "radio"
                #    label _("Rollback Side")
                #    textbutton _("Disable") action Preference("rollback side", "disable")
                #    textbutton _("Left") action Preference("rollback side", "left")
                #    textbutton _("Right") action Preference("rollback side", "right")



                ## Additional vboxes of type "radio_pref" or "check_pref" can be
                ## added here, to add additional creator-defined preferences.

            null height (4 * gui.pref_spacing)

            hbox:
                style_prefix "slider"
                box_wrap True

                vbox:
                    style_prefix "radio"
                    label _("Boil Effect")
                    textbutton _("Be") action SetVariable("persistent.performance_mode", False)
                    textbutton _("Ki") action SetVariable("persistent.performance_mode", True)

                vbox:
                    style_prefix "radio"
                    label _("Parallax Effect")
                    textbutton _("Be") action SetVariable("persistent.parallax_on", True)
                    textbutton _("Ki") action SetVariable("persistent.parallax_on", False)

                vbox:
                    style_prefix "radio"
                    label _("Flickering Images")
                    textbutton _("Be") action SetVariable("persistent.flickering", True)
                    textbutton _("Ki") action SetVariable("persistent.flickering", False)

                #vbox:

                #    label _("Text Speed")

                #    bar value Preference("text speed")

                #    label _("Auto-Forward Time")

                #    bar value Preference("auto-forward time")

                vbox:

                    if config.has_music:
                        label _("Music Volume")

                        hbox:
                            bar value Preference("music volume")

                    if config.has_sound:

                        label _("Sound Volume")

                        hbox:
                            bar value Preference("sound volume")

                            if config.sample_sound:
                                textbutton _("Test") action Play("sound", config.sample_sound)


                    if config.has_voice:
                        label _("Voice Volume")

                        hbox:
                            bar value Preference("voice volume")

                            if config.sample_voice:
                                textbutton _("Test") action Play("voice", config.sample_voice)

                    if config.has_music or config.has_sound or config.has_voice:
                        null height gui.pref_spacing

                        textbutton _("Mute All"):
                            action Preference("all mute", "toggle")
                            style "mute_all_button"


style pref_label is gui_label
style pref_label_text is gui_label_text
style pref_vbox is vbox

style radio_label is pref_label
style radio_label_text is pref_label_text
style radio_button is gui_button
style radio_button_text is gui_button_text
style radio_vbox is pref_vbox

style check_label is pref_label
style check_label_text is pref_label_text
style check_button is gui_button
style check_button_text is gui_button_text
style check_vbox is pref_vbox

style slider_label is pref_label
style slider_label_text is pref_label_text
style slider_slider is gui_slider
style slider_button is gui_button
style slider_button_text is gui_button_text
style slider_pref_vbox is pref_vbox

style mute_all_button is check_button
style mute_all_button_text is check_button_text

style pref_label:
    top_margin gui.pref_spacing
    bottom_margin 3

style pref_label_text:
    yalign 1.0

style pref_vbox:
    xsize 338

style radio_vbox:
    spacing gui.pref_button_spacing

style radio_button:
    properties gui.button_properties("radio_button")
    foreground "gui/button/radio_[prefix_]foreground.png"

style radio_button_text:
    properties gui.button_text_properties("radio_button")

style check_vbox:
    spacing gui.pref_button_spacing

style check_button:
    properties gui.button_properties("check_button")
    foreground "gui/button/check_[prefix_]foreground.png"

style check_button_text:
    properties gui.button_text_properties("check_button")

style slider_slider:
    xsize 525

style slider_button:
    properties gui.button_properties("slider_button")
    yalign 0.5
    left_margin 15

style slider_button_text:
    properties gui.button_text_properties("slider_button")

style slider_vbox:
    xsize 675


## History screen ##############################################################
##
## This is a screen that displays the dialogue history to the player. While
## there isn't anything special about this screen, it does have to access the
## dialogue history stored in _history_list.
##
## https://www.renpy.org/doc/html/history.html

screen history():

    tag menu

    ## Avoid predicting this screen, as it can be very large.
    predict False

    use game_menu(_("History"), scroll=("vpgrid" if gui.history_height else "viewport"), yinitial=1.0):

        style_prefix "history"

        for h in _history_list:

            window:

                ## This lays things out properly if history_height is None.
                has fixed:
                    yfit True

                if h.who:

                    label h.who:
                        style "history_name"
                        substitute False

                        ## Take the color of the who text from the Character, if
                        ## set.
                        if "color" in h.who_args:
                            text_color h.who_args["color"]

                $ what = renpy.filter_text_tags(h.what, allow=gui.history_allow_tags)
                text what:
                    substitute False

        if not _history_list:
            label _("The dialogue history is empty.")


## This determines what tags are allowed to be displayed on the history screen.

define gui.history_allow_tags = { "alt", "noalt" }


style history_window is empty

style history_name is gui_label
style history_name_text is gui_label_text
style history_text is gui_text

style history_text is gui_text

style history_label is gui_label
style history_label_text is gui_label_text

style history_window:
    xfill True
    ysize gui.history_height

style history_name:
    xpos gui.history_name_xpos
    xanchor gui.history_name_xalign
    ypos gui.history_name_ypos
    xsize gui.history_name_width

style history_name_text:
    min_width gui.history_name_width
    text_align gui.history_name_xalign

style history_text:
    xpos gui.history_text_xpos
    ypos gui.history_text_ypos
    xanchor gui.history_text_xalign
    xsize gui.history_text_width
    min_width gui.history_text_width
    text_align gui.history_text_xalign
    layout ("subtitle" if gui.history_text_xalign else "tex")

style history_label:
    xfill True

style history_label_text:
    xalign 0.5


## Help screen #################################################################
##
## A screen that gives information about key and mouse bindings. It uses other
## screens (keyboard_help, mouse_help, and gamepad_help) to display the actual
## help.

screen help():

    tag menu

    default device = "keyboard"

    use game_menu(_("Help"), scroll="viewport"):

        style_prefix "help"

        vbox:
            spacing 23

            hbox:

                textbutton _("Keyboard") action SetScreenVariable("device", "keyboard")
                textbutton _("Mouse") action SetScreenVariable("device", "mouse")

                if GamepadExists():
                    textbutton _("Gamepad") action SetScreenVariable("device", "gamepad")

            if device == "keyboard":
                use keyboard_help
            elif device == "mouse":
                use mouse_help
            elif device == "gamepad":
                use gamepad_help


screen keyboard_help():

    hbox:
        label "Shift+A"
        text _("Opens the accessibility menu.")

    hbox:
        label _("Enter")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Space")
        text _("Advances dialogue without selecting choices.")

    hbox:
        label _("Arrow Keys")
        text _("Navigate the interface.")

    hbox:
        label _("Escape")
        text _("Accesses the game menu.")

    hbox:
        label _("Ctrl")
        text _("Skips dialogue while held down.")

    hbox:
        label _("Tab")
        text _("Toggles dialogue skipping.")

    hbox:
        label _("Page Up")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Page Down")
        text _("Rolls forward to later dialogue.")

    hbox:
        label "H"
        text _("Hides the user interface.")

    hbox:
        label "S"
        text _("Takes a screenshot.")

    hbox:
        label "V"
        text _("Toggles assistive {a=https://www.renpy.org/l/voicing}self-voicing{/a}.")




screen mouse_help():

    hbox:
        label _("Left Click")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Middle Click")
        text _("Hides the user interface.")

    hbox:
        label _("Right Click")
        text _("Accesses the game menu.")

    hbox:
        label _("Mouse Wheel Up\nClick Rollback Side")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Mouse Wheel Down")
        text _("Rolls forward to later dialogue.")


screen gamepad_help():

    hbox:
        label _("Right Trigger\nA/Bottom Button")
        text _("Advances dialogue and activates the interface.")

    hbox:
        label _("Left Trigger\nLeft Shoulder")
        text _("Rolls back to earlier dialogue.")

    hbox:
        label _("Right Shoulder")
        text _("Rolls forward to later dialogue.")


    hbox:
        label _("D-Pad, Sticks")
        text _("Navigate the interface.")

    hbox:
        label _("Start, Guide")
        text _("Accesses the game menu.")

    hbox:
        label _("Y/Top Button")
        text _("Hides the user interface.")

    textbutton _("Calibrate") action GamepadCalibrate()


style help_button is gui_button
style help_button_text is gui_button_text
style help_label is gui_label
style help_label_text is gui_label_text
style help_text is gui_text

style help_button:
    properties gui.button_properties("help_button")
    xmargin 12

style help_button_text:
    properties gui.button_text_properties("help_button")

style help_label:
    xsize 375
    right_padding 30

style help_label_text:
    size gui.text_size
    xalign 1.0
    text_align 1.0



################################################################################
## Additional screens
################################################################################


## Confirm screen ##############################################################
##
## The confirm screen is called when Ren'Py wants to ask the player a yes or no
## question.
##
## https://www.renpy.org/doc/html/screen_special.html#confirm

screen confirm(message, yes_action, no_action):

    ## Ensure other screens do not get input while this screen is displayed.
    modal True

    zorder 200

    style_prefix "confirm"

    add "gui/overlay/confirm.png"

    frame:

        vbox:
            xalign .5
            yalign .5
            spacing 45

            label _(message):
                style "confirm_prompt"
                xalign 0.5

            hbox:
                xalign 0.5
                spacing 150

                textbutton _("Igen") action yes_action
                textbutton _("Nem") action no_action

    ## Right-click and escape answer "no".
    key "game_menu" action no_action


style confirm_frame is gui_frame
style confirm_prompt is gui_prompt
style confirm_prompt_text is gui_prompt_text
style confirm_button is gui_medium_button
style confirm_button_text is gui_medium_button_text

style confirm_frame:
    background Frame([ "gui/confirm_frame.png", "gui/frame.png"], gui.confirm_frame_borders, tile=gui.frame_tile)
    padding gui.confirm_frame_borders.padding
    xalign .5
    yalign .5

style confirm_prompt_text:
    text_align 0.5
    layout "subtitle"

style confirm_button:
    properties gui.button_properties("confirm_button")

style confirm_button_text:
    properties gui.button_text_properties("confirm_button")


## Skip indicator screen #######################################################
##
## The skip_indicator screen is displayed to indicate that skipping is in
## progress.
##
## https://www.renpy.org/doc/html/screen_special.html#skip-indicator

screen skip_indicator():

    zorder 100
    style_prefix "skip"

    frame:

        hbox:
            spacing 9

            text _("Kihagyás")

            text "▸" at delayed_blink(0.0, 1.0) style "skip_triangle"
            text "▸" at delayed_blink(0.2, 1.0) style "skip_triangle"
            text "▸" at delayed_blink(0.4, 1.0) style "skip_triangle"


## This transform is used to blink the arrows one after another.
transform delayed_blink(delay, cycle):
    alpha .5

    pause delay

    block:
        linear .2 alpha 1.0
        pause .2
        linear .2 alpha 0.5
        pause (cycle - .4)
        repeat


style skip_frame is empty
style skip_text is gui_text
style skip_triangle is skip_text

style skip_frame:
    ypos gui.skip_ypos
    background Frame("gui/skip.png", gui.skip_frame_borders, tile=gui.frame_tile)
    padding gui.skip_frame_borders.padding

style skip_text:
    size gui.notify_text_size

style skip_triangle:
    ## We have to use a font that has the BLACK RIGHT-POINTING SMALL TRIANGLE
    ## glyph in it.
    font "DejaVuSans.ttf"


## Notify screen ###############################################################
##
## The notify screen is used to show the player a message. (For example, when
## the game is quicksaved or a screenshot has been taken.)
##
## https://www.renpy.org/doc/html/screen_special.html#notify-screen

screen notify(message):

    zorder 100
    style_prefix "notify"

    frame at notify_appear:
        text "[üzenet!tq]"

    timer 3.25 action Hide('notify')


transform notify_appear:
    on show:
        alpha 0
        linear .25 alpha 1.0
    on hide:
        linear .5 alpha 0.0


style notify_frame is empty
style notify_text is gui_text

style notify_frame:
    ypos gui.notify_ypos

    background Frame("gui/notify.png", gui.notify_frame_borders, tile=gui.frame_tile)
    padding gui.notify_frame_borders.padding

style notify_text:
    properties gui.text_properties("notify")


## NVL screen ##################################################################
##
## This screen is used for NVL-mode dialogue and menus.
##
## https://www.renpy.org/doc/html/screen_special.html#nvl


screen nvl(dialogue, items=None):

    window:
        style "nvl_window"

        has vbox:
            spacing gui.nvl_spacing

        ## Displays dialogue in either a vpgrid or the vbox.
        if gui.nvl_height:

            vpgrid:
                cols 1
                yinitial 1.0

                use nvl_dialogue(dialogue)

        else:

            use nvl_dialogue(dialogue)

        ## Displays the menu, if given. The menu may be displayed incorrectly if
        ## config.narrator_menu is set to True, as it is above.
        for i in items:

            textbutton i.caption:
                action i.action
                style "nvl_button"

    add SideImage() xalign 0.0 yalign 1.0


screen nvl_dialogue(dialogue):

    for d in dialogue:

        window:
            id d.window_id

            fixed:
                yfit gui.nvl_height is None

                if d.who is not None:

                    text d.who:
                        id d.who_id

                text d.what:
                    id d.what_id


## This controls the maximum number of NVL-mode entries that can be displayed at
## once.
define config.nvl_list_length = gui.nvl_list_length

style nvl_window is default
style nvl_entry is default

style nvl_label is say_label
style nvl_dialogue is say_dialogue

style nvl_button is button
style nvl_button_text is button_text

style nvl_window:
    xfill True
    yfill True

    background "gui/nvl.png"
    padding gui.nvl_borders.padding

style nvl_entry:
    xfill True
    ysize gui.nvl_height

style nvl_label:
    xpos gui.nvl_name_xpos
    xanchor gui.nvl_name_xalign
    ypos gui.nvl_name_ypos
    yanchor 0.0
    xsize gui.nvl_name_width
    min_width gui.nvl_name_width
    text_align gui.nvl_name_xalign

style nvl_dialogue:
    xpos gui.nvl_text_xpos
    xanchor gui.nvl_text_xalign
    ypos gui.nvl_text_ypos
    xsize gui.nvl_text_width
    min_width gui.nvl_text_width
    text_align gui.nvl_text_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_thought:
    xpos gui.nvl_thought_xpos
    xanchor gui.nvl_thought_xalign
    ypos gui.nvl_thought_ypos
    xsize gui.nvl_thought_width
    min_width gui.nvl_thought_width
    text_align gui.nvl_thought_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_button:
    properties gui.button_properties("nvl_button")
    xpos gui.nvl_button_xpos
    xanchor gui.nvl_button_xalign

style nvl_button_text:
    properties gui.button_text_properties("nvl_button")



################################################################################
## Mobile Variants
################################################################################

style pref_vbox:
    variant "medium"
    xsize 675

## Since a mouse may not be present, we replace the quick menu with a version
## that uses fewer and bigger buttons that are easier to touch.
screen quick_menu():
    variant "touch"

    zorder 100

    if quick_menu:

        hbox:
            style_prefix "quick"

            xalign 0.5
            yalign 1.0

            textbutton _("Vissza") action Rollback()
            textbutton _("Kihagy") action Skip() alternate Skip(fast=True, confirm=True)
            textbutton _("Auto") action Preference("auto-forward", "toggle")
            textbutton _("Menu") action ShowMenu()


style window:
    variant "small"
    background "gui/phone/textbox.png"

style radio_button:
    variant "small"
    foreground "gui/phone/button/radio_[prefix_]foreground.png"

style check_button:
    variant "small"
    foreground "gui/phone/button/check_[prefix_]foreground.png"

style nvl_window:
    variant "small"
    background "gui/phone/nvl.png"

style main_menu_frame:
    variant "small"
    background "gui/phone/overlay/main_menu.png"

style game_menu_outer_frame:
    variant "small"
    background "gui/phone/overlay/game_menu.png"

style game_menu_navigation_frame:
    variant "small"
    xsize 510

style game_menu_content_frame:
    variant "small"
    top_margin 0

style pref_vbox:
    variant "small"
    xsize 600

style bar:
    variant "small"
    ysize gui.bar_size
    left_bar Frame("gui/phone/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/phone/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    variant "small"
    xsize gui.bar_size
    top_bar Frame("gui/phone/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/phone/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    variant "small"
    ysize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    variant "small"
    xsize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)



style slider:
    variant "small"
    ysize gui.slider_size
    base_bar Frame("gui/phone/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/horizontal_[prefix_]thumb.png"

style vslider:
    variant "small"
    xsize gui.slider_size
    base_bar Frame("gui/phone/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/vertical_[prefix_]thumb.png"

style slider_vbox:
    variant "small"
    xsize None

style slider_slider:
    variant "small"
    xsize 900
